==> haskell-hls-cabal-fmt-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-fmt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-2.1.0.0-8aTNBd7zEFf4IK9JeRaANQ
key:                  hls-cabal-fmt-plugin-2.1.0.0-8aTNBd7zEFf4IK9JeRaANQ
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  eca3da599119af131b3a3bf69aba8451
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-2.1.0.0-8aTNBd7zEFf4IK9JeRaANQ
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-types-2.0.1.0-KsWoulY9wwoKMSLEqbLHCK mtl-2.3.1 process-1.6.19.0
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-cabal-fmt-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-cabal-fmt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-cabal-fmt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-cabal-fmt-plugin-2.1.0.0-CQgYWL01IPhAVTavDAzJne
key:                  hls-cabal-fmt-plugin-2.1.0.0-CQgYWL01IPhAVTavDAzJne
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           jana.chadt@nets.at
author:               The Haskell IDE Team
synopsis:             Integration with the cabal-fmt code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  2a70036fcb74b204dee45720573a7090
exposed:              True
exposed-modules:      Ide.Plugin.CabalFmt
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-cabal-fmt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-cabal-fmt-plugin
hs-libraries:         HShls-cabal-fmt-plugin-2.1.0.0-CQgYWL01IPhAVTavDAzJne
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB
    lsp-types-2.0.1.0-16awFyiKGg1Iy6lHArG7S3 mtl-2.3.1 process-1.6.19.0
    text-2.0.2 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-cabal-fmt-plugin/html/hls-cabal-fmt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-cabal-fmt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
